#
# spec file for package kpublictransport
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kpublictransport
Version:        24.12.3
Release:        1.2
Summary:        QML imports for querying public transport data
License:        LGPL-2.0-or-later
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  bison
BuildRequires:  doxygen
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6NetworkManagerQt) >= %{kf6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(zlib)

%description
A library for access realtime public transport data and for performing public
ransport journey queries.

%package imports
Summary:        QML Imports for using kpublictransport

%description imports
A library for access realtime public transport data and for performing public
ransport journey queries. QML imports.

%package -n libKPublicTransport1
Summary:        Library for querying public transport data
Requires:       kpublictransport >= %{version}

%description -n libKPublicTransport1
A library for access realtime public transport data and for performing public
ransport journey queries.

%package -n libKPublicTransportOnboard1
Summary:        Library for querying public transport data onboard trains
Requires:       libKPublicTransport1 = %{version}

%description -n libKPublicTransportOnboard1
A library for access realtime public transport data and for performing public
transport journey queries. This package contains a library to determine 
the presence onboard of a train using WiFi SSIDs and provide journey 
details.

%package devel
Summary:        Library for querying public transport data
Requires:       libKPublicTransport1 = %{version}
Requires:       libKPublicTransportOnboard1 = %{version}
Requires:       cmake(Qt6Gui) >= %{qt6_version}
Requires:       pkgconfig(zlib)

%description devel
A library for access realtime public transport data and for performing public
ransport journey queries.Development files.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 \
  -DBUILD_TESTING:BOOL=TRUE \
  -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%check
%ctest

%ldconfig_scriptlets -n libKPublicTransport1
%ldconfig_scriptlets -n libKPublicTransportOnboard1

%files
%{_kf6_debugdir}/org_kde_kpublictransport.categories
%{_kf6_debugdir}/org_kde_kpublictransport_onboard.categories

%files imports
%{_kf6_qmldir}/org/kde/kpublictransport/

%files -n libKPublicTransport1
%license LICENSES/*
%{_kf6_libdir}/libKPublicTransport.so.*

%files -n libKPublicTransportOnboard1
%{_kf6_libdir}/libKPublicTransportOnboard.so.*

%files devel
%doc %{_kf6_qchdir}/KPublicTransport.*
%{_includedir}/KPublicTransport/
%{_kf6_cmakedir}/KPublicTransport/
%{_kf6_libdir}/libKPublicTransport.so
%{_kf6_libdir}/libKPublicTransportOnboard.so

%files lang -f %{name}.lang

%changelog
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- Changes since 24.12.2:
  * Also add location name to stop place reference based OJP requests
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- Changes since 24.12.1:
  * Set API keys for HSL and Waltti backends as well
  * Switch to Entur's v3 API
  * Try harder to determine OTP line modes
  * Switch Transitous to the new MOTIS v2 API
  * DB: Handle NS International tickets
  * Handle transfer sections in the new DB API
  * Parse occupancy information also for the entire section
  * Add test for cancelled journeys in the new DB API
  * Update Rolph endpoint URL
  * Remove Australian Navitia backend configuration
  * Restore Digitransit support now that they require an API key
  * Reduce excessive debug output
  * Switch to DB's new proxied Hafas API by default
  * Switch the Hafas request unit tests to use ÖBB instead of DB
  * EFA: Improve arrival/departure time parsing for intermediate stops
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * Fix determining station name for arrival queries
  * Add support for DB's proxied Hafas API
  * Namespace Hafas identifiers for locations
  * Make Hafas remark metadata externally accessible
  * Isolate test from cached data on the host
  * Factor out Hafas load level parsing
  * Add Hafas location identifier parser
  * Adapt to changes in the MOTIS v2 vehicle parking modes
  * Ensure WALK is always in the access/egress modes for MOTIS v2 requests
  * Adapt to MOTIS v2 rental vehicle form factor API changes
  * Improve merging of features with conditional/limited availability
  * Propagate disruption effects when setting arrival/departure stopovers
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Changes since 24.11.90:
  * Sync OSM data types from KOSMIndoorMap (kde#497034)
  * Remove ZVV configuration
  * Update VRS client certificate
  * Discard CA certificates found in PKCS12 bundles
  * Refactor IVV ASS request generation and allow to configure extra arguments
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * Update line metadata from OSM/Wikidata
  * Consider more Wikidata properties for line logos
  * Resize some of the icons to 22px
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes since 24.08.3, only listing bugfixes:
  * Remove DE and ES coverage from Navitia (kde#494608)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Fix arrival delay parsing in NS onboard API
  * Decode JSON numbers provided as strings as well
  * Don't encode timezone information separately in UTC
  * Add onboard backend for nstrein
  * Remove DE and ES coverage from Navitia (kde#494608)
  * Add namespace for Android as required by newer gradle versions
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * srbijavoz: Make station matching stricter
  * Update Srbija Voz station data
  * Promote ee_peatus to regularCoverage
  * ee_peatus: Remove custom certificate
  * motisparser: trim whitespace from the line name
  * Restore downstream Transitous coverage data adjustments
  * Update Transitous coverage data from Transport API Respository
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Update Hafas feature code mapping for codes observed at BLS
  * Add Hafas vehicle feature codes used by NASA
  * Downgrade coverage quality for France for ÖBB
  * Add more Hafas feature codes observed in Switzerland
  * Update ZVV API key
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes to list here.
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Update DB and ÖBB coverage data from Transport API repository
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Remove PKP provider
  * Fix dangling reference
  * Make the pointless path filter for journey results actually work again
  * Factor out journey filter thresholds
  * Use the new location-based timezone propagation also for the onboard API
  * Fill in missing timezones based on locations from KI18nLocaleData
  * Add another Hafas coach/vehicle feature mapping
  * Handle invalid coordinates when parsing Navitia responses
  * transitous: Move NL and BE to regularCoverage
  * db, transitous: Sync geometry
  * Add attribution data for Transitous
  * Map two more Hafas feature message codes
  * Handle non-WGS84 coordinates in EFA responses
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Fix locale overriding in request unit tests (kde#482357)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Improve coach background color on incomplete coach type information
  * Actually check the results of the Hafas vehicle result parsing tests
  * Check car type before deriving class from UIC coach number
  * Add support for Hafas rtMode TripSearch configuration parameter
  * Increase DB Hafas API and extension versions
  * Fix locale overriding in request unit tests (kde#482357)
  * Fix copy/paste mistake in caching negative journey query results
  * Don't modify the request after we used it for a cache lookup
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Fix copy/paste mistake in caching negative journey query results
  * Don't modify the request after we used it for a cache lookup
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Add Eurostar onboard SSID
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Correctly detect past canceled stops in DB ICE onboard journey data
  * Fix asymmetric location type comparison
  * Handle canceled stops in DB ICE onboard API journey data
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * test: querytest: Fixup au_navitia locations
  * networks: au_navitia: Use stop_point instead of stop_area
  * networks: au_navitia: Expand to all of Australia
  * networks: au_navitia: Fixup latitude and longitude
  * Fix typo in onboard API header installation
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Remove coverage data without polygons from BVG and VBB
  * Don't limit vehicle layout queries to backends with realtime coverage
  * Remove the restriction for ÖBB vehicle layout requests on Austria
  * Support vehicle layouts for a few more ÖBB train types
  * Add support for ÖBB onboard API
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes to list here.
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Drop implausible section paths
  * Apply check for physical limits also to walking sections
  * Fix long distance bus line mode for VOR
  * Remove dead OTP endpoints in Münster and Ulm
  * Also request the top-level transport mode for Entur stopover queries
  * Parse OTP transit legs without a transport mode subtype correctly
  * Make VRS work again
  * Add support for PKCS#12 client certificate bundles
  * Apply SSL configuration to IVV ASS network requests as well
  * Don't crash when setting custom QNAM when there isn't a default one yet
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Exclude test input files that don't pass the JSON validation CI step
  * Drop substring notes during notes merging
  * Fix typo in parsing expected arrival times in DB Zugportal journeys
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Propagate query job deletion to network jobs
  * Do name-based EFA location searches with type_sf=any
  * Add support for MAV onboard API
  * Add FlixTrain Wi-Fi SSID
  * Check for valid position numbers more strictly
  * Fix typo in CD Railjet WiFi SSID
  * Add UIC code of CD to backends that cover Czechia
  * Set proper polygons for all ÖBB coverage areas
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Add UIC coach sub-type mappings for CH and FR
  * Add overnight train coach types and parse corresponding UIC coach types
  * Include NightJet trains in supported types of the ÖBB vehicle layout API
  * Port to ECMQmlModule
  * Update coverage polygons from the Transport API Repository
  * Rewrite the train coach element rendering
  * Check name-based location search results for plausibility
  * Fix the backend identifier
  * tests: querytest: un_navitia: Add a Queensland test case
  * Allow to show headers in qtc6
  * Support EFA floor level difference attributes
  * Make isBackendEnabled() accessible from QML
  * Only list covered countries in the location picker
  * Make backend and coverage area objects accessbile from QML
  * Prefer nationwide providers for location searches with a known country
  * Add a configurable query delay for the location query model
  * Add a location history model
  * Remove superfluous export macro
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Disambiguate station name used in the Navitia name-based query tests
  * Fix Navitia location queries for rental bike stations and any type
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Also register RentalVehicleStation for use from QML
  * Parse alternative Hafas platform format as well
  * Remove superfluous export macro
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Don't truncate path line segment lengths to integers
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes to list here.
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Changes since 21.08.2:
  * Update SNCB certificate
  * Update OTP Ulm rental vehicle configuration
  * Pass along floating rented vehicle data correctly
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Switch stadtnavi.de to OTP2
  * Correctly filter OTP results for discarded sharing networks
  * Only cache OTP location results if they contain no realtime elements
  * Consider all location request parameters for computing the cache key
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Work around CMake Protobuf support not dealing with missing protoc
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * Propagate static timezones to intermediate stops as well
  * Add missing timezone for VRR
  * Propagate merged line data to intermediate stops
  * The isspace/isctrl/etc functions require unsigned char as input
  * Properly handle empty path sections in Hafas responses
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes to list here.
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Fix parsing of numeric GBFS station ids
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Fix cmake policy CMP0115 warning
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Set SOVERSION to a fixed value rather than the release service version
  * Disable Hafas binary journey queries on big endian systems
- Drop upstream patch:
  * 0001-Disable-Hafas-binary-journey-queries-on-big-endian-s.patch
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80.
  * New feature release
- kpublictransport is now released using the KDE release service.
- Add upstream patch:
  * 0001-Disable-Hafas-binary-journey-queries-on-big-endian-s.patch
* Mon Jul 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit
